/*
 * Copyright 2024 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.tig.server;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;

public abstract class ServerMultiThreaded {
	public class Worker implements Runnable {
		private Socket s;
		public Worker(Socket s) {
			this.s = s;
		}
		public void run() {
            try {
				process(s);
				s.close();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}
	public abstract int getPort();
	public abstract void process(Socket s) throws IOException;
	public void run() throws IOException {
        ServerSocket ss = new ServerSocket(getPort());
        while(true) {
            Socket s = ss.accept();
            Worker w = new Worker(s);
            Thread t = new Thread(w);
            t.start();
        }
	}
}
